
convolvecl
==========

**convolution of angular power spectra**

This is a minimal Python package for convolution of angular power spectra, in
order to compute the angular power spectrum of a product of spherical functions.
Computation is currently limited to the mixing matrix.

The package can be installed using pip:

    pip install convolvecl

Then import the `mixmat` function from the package:

    from convolvecl import mixmat

For more information, please see the [documentation].

Current functionality covers the absolutely minimal use case.  Please open an
issue on GitHub if you would like to see anything added.

[documentation]: https://cltools.readthedocs.io/convolvecl/
